@@ -14,12 +14,13 @@ import python  # NOQA
 import util  # NOQA
 
 
-VERSION = (1, 6, 1)
+VERSION = (1, 6, 2)
 __version__ = '.'.join(map(str, VERSION))
 
 
 DESCRIPTION = (
-    'Update python dependencies for your project with git integration\n'
+    'Update python and node dependencies for your project with git '
+    'integration\n\n'
     'https://github.com/albertyw/req-update'
 )
 
@@ -38,24 +39,36 @@ class ReqUpdate():
         self.node = node.Node()
         self.node.util = self.util
 
-    def main(self) -> None:
-        """ Update all dependencies """
+    def main(self) -> bool:
+        """
+        Update all dependencies
+        Return if updates were made
+        """
         self.get_args()
         branch_created = False
         self.util.check_repository_cleanliness()
+        updates_made = False
         if self.python.check_applicable():
             if not branch_created:
                 self.util.create_branch()
                 branch_created = True
-            self.python.update_install_dependencies()
+            python_updates = self.python.update_install_dependencies()
+            updates_made = updates_made or python_updates
         if self.node.check_applicable():
             if not branch_created:
                 self.util.create_branch()
                 branch_created = True
-            self.node.update_install_dependencies()
+            node_updates = self.node.update_install_dependencies()
+            updates_made = updates_made or node_updates
+        if branch_created and not updates_made:
+            self.util.rollback_branch()
+        return updates_made
 
     def get_args(self) -> argparse.Namespace:
-        parser = argparse.ArgumentParser(description=DESCRIPTION)
+        parser = argparse.ArgumentParser(
+            description=DESCRIPTION,
+            formatter_class=argparse.RawTextHelpFormatter,
+        )
         parser.add_argument(
             '-p',
             '--push',
